#!/usr/bin/env python
"""Produce events concerning Android hardware (battery)"""
import os.path
import argparse
from runparts import runparts
import time

plug = 'plug'
unplug = 'unplug'

def main():
    """Detect plug events and runs the executables in the matching folder."""
    parser = argparse.ArgumentParser()
    parser.add_argument(
        '--folder', '-f', default="events",
        help='folder containing the folders to run in case of event')
    parser.add_argument(
        '--poll_period', '-p', type=int, default=60,
        help='sleeping time between two polls')
    args = parser.parse_args()

    toRun = None
    charge = poll()
    while True:
        data = poll()
        if data != charge:
            charge = data
            if charge in ('Charging\n', 'Full\n'):
                toRun = plug
            elif charge == 'Discharging\n':
                toRun = unplug
            if toRun:
                runparts.runparts(os.path.join(args.folder, toRun))
        time.sleep(args.poll_period)

def poll():
    """Polls the battery status"""
    chargeFile = open('/sys/class/power_supply/battery/status')
    data = chargeFile.read()
    chargeFile.close()
    return data

if __name__ == '__main__':
    main()
