"""Class to help foresee unplugs"""
import math
import time

plug = 'plug'
unplug = 'unplug'

class Calculator:
    """A class to calculate time left before next unplug"""
    def __init__(self):
        self.date = 0.
        self.squares = 0.
        self.weight = 0.
        self.state = None

    def add(self, date, event):
        """Add an hour to the list of known hours 
        and return the time in seconds to the next wake.
        
        date: time.struct_time
        event: string
        """
        if event != unplug:
            return self.get()
        new = date.tm_hour * 60 + date.tm_min
        self.state = event
        self.weight += 1
        self.date += ((new - self.date)/self.weight + 1440) % 1440
        self.squares += (new*new - self.squares)/self.weight
        return self.get()

    def get(self):
        """Return the time in seconds to next wake without adding any value."""
        now = time.localtime()
        last = self.date - now.tm_hour * 60 - now.tm_min
        sigma = math.sqrt(self.squares - self.date ** 2)
        result = int((last - 3 * sigma - 1 + 1440) % 1440 * 60)
        if result:
            return result
        else:
            return 86400
