#!/usr/bin/env python
"""Learn from plug events and foresee them"""
import time
import os.path
import socket
from predictd import foresee
from runparts import runparts
import argparse
import sqlite3

dateFormat = '%w %Y %m %d %H %M %S'

def main():
    """Learn from plug events and run scripts in the appropriate folder."""
    parser = argparse.ArgumentParser()
    parser.add_argument(
        '--port', '-p', type=int, default=50008,
        help='port on which the daemon listens for events')
    parser.add_argument(
        '--folder', '-f', default="learned",
        help='folder containing the folders to run in case of event')
    parser.add_argument(
        '--memory', '-m', default="memory.db",
        help='file to store the learning database')
    args = parser.parse_args()

    host = ''
    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    sock.bind((host, args.port))
    sock.listen(1)
    state = None
    foreseer = foresee.Calculator()
    sleepTime = 0

    database = sqlite3.connect(args.memory)
    with database:
        curs = database.cursor()
        curs.execute("CREATE TABLE IF NOT EXISTS "
                    + "Events (date TEXT, event TEXT)")
        curs.execute("SELECT * FROM Events")
        for event in curs.fetchall():
            sleepTime = foreseer.add(
                time.strptime(event[0], dateFormat), event[1])

    while True:
        if sleepTime:
            sock.settimeout(sleepTime)
        try:
            conn, _ = sock.accept()
            recv = conn.recv(1024)
            data = recv.split(' ', 1)
            data[1] = data[1].lstrip()
            state = data[0]
            remind(data[1], state, args.memory)
            runparts.runparts(
                os.path.join(args.folder, state))

            sleepTime = foreseer.add(
                time.strptime(data[1], dateFormat), state)

        except socket.timeout:
            runparts.runparts(
                os.path.join(args.folder, foresee.unplug))
            sleepTime = foreseer.get()
    return

def tell(string, port):
    """Comunicate with learning daemon. 
    The port must be the same as the one the daemon is listening to."""
    host = '127.0.0.1'
    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    sock.connect((host, port))
    sock.sendall(
        string + ' ' + time.strftime(dateFormat))
    sock.close()
    return

def remind(date, event, memory):
    """Put event with its date into learning database."""
    database = sqlite3.connect(memory)
    with database:
        curs = database.cursor()
        curs.execute("INSERT INTO Events VALUES(?, ?)", (date, event))
        database.commit()
    return

if __name__ == '__main__':
    main()
